@@ -4,9 +4,9 @@ import packaging.version
 
 from . import fixtures
 from importlib_metadata import (
-    Distribution,
     MetadataPathFinder,
     _compat,
+    distributions,
     version,
 )
 
@@ -43,13 +43,6 @@ class FinderTests(fixtures.Fixtures, unittest.TestCase):
         _compat.disable_stdlib_finder()
 
 
-class LocalProjectTests(fixtures.LocalPackage, unittest.TestCase):
-    def test_find_local(self):
-        dist = Distribution._local()
-        assert dist.metadata['Name'] == 'local-pkg'
-        assert dist.version == '2.0.1'
-
-
 class DistSearch(unittest.TestCase):
     def test_search_dist_dirs(self):
         """
@@ -59,3 +52,16 @@ class DistSearch(unittest.TestCase):
         """
         res = MetadataPathFinder._search_paths('any-name', [])
         assert list(res) == []
+
+    def test_interleaved_discovery(self):
+        """
+        When the search is cached, it is
+        possible for searches to be interleaved, so make sure
+        those use-cases are safe.
+
+        Ref #293
+        """
+        dists = distributions()
+        next(dists)
+        version('importlib_metadata')
+        next(dists)
