@@ -224,12 +224,20 @@ class InaccessibleSysPath(fixtures.OnSysPath, ffs.TestCase):
 class TestEntryPoints(unittest.TestCase):
     def __init__(self, *args):
         super().__init__(*args)
-        self.ep = importlib_metadata.EntryPoint('name', 'value', 'group')
+        self.ep = importlib_metadata.EntryPoint(
+            name='name', value='value', group='group'
+        )
 
     def test_entry_point_pickleable(self):
         revived = pickle.loads(pickle.dumps(self.ep))
         assert revived == self.ep
 
+    def test_positional_args(self):
+        """
+        Capture legacy (namedtuple) construction, discouraged.
+        """
+        EntryPoint('name', 'value', 'group')
+
     def test_immutable(self):
         """EntryPoints should be immutable"""
         with self.assertRaises(AttributeError):
@@ -264,8 +272,8 @@ class TestEntryPoints(unittest.TestCase):
         """
         sorted(
             [
-                EntryPoint('b', 'val', 'group'),
-                EntryPoint('a', 'val', 'group'),
+                EntryPoint(name='b', value='val', group='group'),
+                EntryPoint(name='a', value='val', group='group'),
             ]
         )
 
